"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const plugin_utilities_1 = require("@rxap/plugin-utilities");
const promises_1 = require("fs/promises");
const run_commands_impl_1 = require("nx/src/executors/run-commands/run-commands.impl");
const path_1 = require("path");
function toArgs(options) {
    const args = [];
    for (const [key, value] of Object.entries(options)) {
        if (Array.isArray(value)) {
            for (const item of value) {
                args.push(`--${key} ${item}`);
            }
        }
        else {
            if (typeof value === 'boolean') {
                if (value) {
                    args.push(`--${key}`);
                }
                else {
                    args.push(`--${key} ${value}`);
                }
            }
            else {
                args.push(`--${key} ${value}`);
            }
        }
    }
    return args;
}
const runExecutor = (options, context) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    var _a;
    console.log('Executor ran for Build', options);
    const projectRoot = (0, plugin_utilities_1.GetProjectRoot)(context);
    if (!((_a = options.outputPaths) === null || _a === void 0 ? void 0 : _a.length)) {
        options.outputPaths = [(0, path_1.join)(projectRoot, 'docs')];
    }
    const { outputPaths, html, json, plugins, markdown, wiki } = options, argOptions = tslib_1.__rest(options, ["outputPaths", "html", "json", "plugins", "markdown", "wiki"]);
    for (const outputPath of outputPaths) {
        yield (0, promises_1.rm)(outputPath, { recursive: true, force: true });
        if (json) {
            const result = yield (0, run_commands_impl_1.default)({
                command: 'typedoc',
                color: true,
                args: toArgs(argOptions).concat(`--json ${(0, path_1.join)(outputPath, 'documentation.json')}`),
                __unparsed__: [],
            }, context);
            if (!result.success) {
                return Object.assign(Object.assign({}, result), { success: false });
            }
        }
        if (html) {
            const result = yield (0, run_commands_impl_1.default)({
                command: 'typedoc',
                color: true,
                args: toArgs(argOptions).concat(`--html ${(0, path_1.join)(outputPath, 'html')}`),
                __unparsed__: [],
            }, context);
            if (!result.success) {
                return Object.assign(Object.assign({}, result), { success: false });
            }
        }
        if (markdown) {
            const result = yield (0, run_commands_impl_1.default)({
                command: 'typedoc',
                color: true,
                args: toArgs(argOptions).concat(`--out ${(0, path_1.join)(outputPath, 'markdown')}`, '--plugin typedoc-plugin-markdown'),
                __unparsed__: [],
            }, context);
            if (!result.success) {
                return Object.assign(Object.assign({}, result), { success: false });
            }
        }
        if (wiki) {
            const result = yield (0, run_commands_impl_1.default)({
                command: 'typedoc',
                color: true,
                args: toArgs(argOptions).concat(`--out ${(0, path_1.join)(outputPath, 'wiki')}`, '--plugin typedoc-plugin-markdown', '--plugin typedoc-github-wiki-theme'),
                __unparsed__: [],
            }, context);
            if (!result.success) {
                return Object.assign(Object.assign({}, result), { success: false });
            }
        }
        if (plugins === null || plugins === void 0 ? void 0 : plugins.length) {
            const result = yield (0, run_commands_impl_1.default)({
                command: 'typedoc',
                color: true,
                args: toArgs(argOptions).concat(`--out ${outputPath}`, ...plugins.map(plugin => `--plugin ${plugin}`)),
                __unparsed__: [],
            }, context);
            if (!result.success) {
                return Object.assign(Object.assign({}, result), { success: false });
            }
        }
    }
    return {
        success: true
    };
});
exports.default = runExecutor;
//# sourceMappingURL=executor.js.map