"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initLibraryGenerator = initLibraryGenerator;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const utilities_1 = require("@rxap/utilities");
const workspace_utilities_1 = require("@rxap/workspace-utilities");
const init_project_1 = require("./init-project");
const init_workspace_1 = require("./init-workspace");
function skipProject(tree, options, project, projectName) {
    if (options.project === projectName) {
        return false;
    }
    if ((0, workspace_utilities_1.IsWorkspaceProject)(project) && tree.exists('tsconfig.typedoc.json')) {
        return false;
    }
    if (projectName === 'rxap') {
        return true;
    }
    if ((0, workspace_utilities_1.SkipNonLibraryProject)(tree, options, project, projectName)) {
        return true;
    }
    return false;
}
function initLibraryGenerator(tree, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        var _a, _b;
        (_a = options.project) !== null && _a !== void 0 ? _a : (options.project = undefined);
        (_b = options.projects) !== null && _b !== void 0 ? _b : (options.projects = []);
        if (options.project) {
            (0, utilities_1.CoerceArrayItems)(options.projects, [options.project]);
        }
        console.log('typedoc library init generator:', options);
        yield (0, init_workspace_1.initWorkspace)(tree, options);
        if (!options.skipProjects) {
            for (const [projectName, project] of (0, devkit_1.getProjects)(tree).entries()) {
                if (skipProject(tree, options, project, projectName)) {
                    continue;
                }
                yield (0, init_project_1.initProject)(tree, projectName, project, options);
                (0, workspace_utilities_1.GenerateSerializedSchematicFile)(tree, (0, workspace_utilities_1.GetProjectRoot)(tree, projectName), '@rxap/plugin-typedoc', 'init-library', options);
                (0, devkit_1.updateProjectConfiguration)(tree, projectName, project);
            }
        }
        if (!options.skipFormat) {
            yield (0, devkit_1.formatFiles)(tree);
        }
    });
}
exports.default = initLibraryGenerator;
//# sourceMappingURL=generator.js.map