"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initProject = initProject;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const workspace_utilities_1 = require("@rxap/workspace-utilities");
const path_1 = require("path");
const coerce_git_ignore_1 = require("../../lib/coerce-git-ignore");
const coerce_typedoc_ts_config_1 = require("../../lib/coerce-typedoc-ts-config");
const update_project_ng_package_configuration_1 = require("./update-project-ng-package-configuration");
function initProject(tree, projectName, project, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        console.log(`init typedoc library project: ${projectName}`);
        if ((0, workspace_utilities_1.IsPublishable)(tree, project)) {
            if ((0, workspace_utilities_1.IsAngularProject)(project)) {
                (0, update_project_ng_package_configuration_1.updateProjectNgPackageConfiguration)(tree, project);
            }
            else if ((0, workspace_utilities_1.HasTarget)(tree, projectName, 'build')) {
                const target = (0, workspace_utilities_1.GetTarget)(project, 'build');
                if (target.options['assets']) {
                    const projectRoot = (0, workspace_utilities_1.GetProjectRoot)(tree, projectName);
                    (0, workspace_utilities_1.CoerceAssets)(target.options.assets, [(0, path_1.join)(projectRoot, 'docs')]);
                }
            }
        }
        if ((0, workspace_utilities_1.IsWorkspaceProject)(project)) {
            const includeList = Array.from((0, devkit_1.getProjects)(tree))
                .filter(([_, project]) => !(0, workspace_utilities_1.IsWorkspaceProject)(project))
                .filter(([projectName]) => tree.exists((0, path_1.join)((0, workspace_utilities_1.GetProjectRoot)(tree, projectName), 'tsconfig.typedoc.json')))
                .map(([projectName]) => (0, workspace_utilities_1.GetProjectSourceRoot)(tree, projectName))
                .map(sourceRoot => [
                (0, path_1.join)(sourceRoot, 'lib/**/*.ts'),
                (0, path_1.join)(sourceRoot, 'index.ts'),
            ])
                .flat();
            (0, coerce_typedoc_ts_config_1.CoerceTypedocTsConfig)(tree, (0, workspace_utilities_1.GetWorkspaceProjectName)(tree), includeList);
            (0, workspace_utilities_1.UpdateJsonFile)(tree, typedoc => {
                var _a, _b, _c, _d;
                var _e, _f, _g;
                typedoc['entryPointStrategy'] = 'packages';
                typedoc['includeVersion'] = false;
                (_a = typedoc['packageOptions']) !== null && _a !== void 0 ? _a : (typedoc['packageOptions'] = {});
                (_b = (_e = typedoc['packageOptions'])['tsconfig']) !== null && _b !== void 0 ? _b : (_e['tsconfig'] = 'tsconfig.typedoc.json');
                (_c = (_f = typedoc['packageOptions'])['includeVersion']) !== null && _c !== void 0 ? _c : (_f['includeVersion'] = true);
                (_d = (_g = typedoc['packageOptions'])['entryPoints']) !== null && _d !== void 0 ? _d : (_g['entryPoints'] = ["src/index.ts"]);
                typedoc['entryPoints'] = Array.from((0, devkit_1.getProjects)(tree))
                    .filter(([_, project]) => !(0, workspace_utilities_1.IsWorkspaceProject)(project))
                    .filter(([projectName]) => tree.exists((0, path_1.join)((0, workspace_utilities_1.GetProjectRoot)(tree, projectName), 'tsconfig.typedoc.json')))
                    .map(([projectName]) => (0, workspace_utilities_1.GetProjectRoot)(tree, projectName));
            }, 'typedoc.json', { create: true });
        }
        else {
            (0, coerce_typedoc_ts_config_1.CoerceTypedocTsConfig)(tree, projectName, ['src/index.ts', 'src/lib/**/*.ts']);
        }
        (0, coerce_git_ignore_1.CoerceGitIgnore)(tree, projectName);
        if ((0, workspace_utilities_1.isJetbrainsProject)(tree)) {
            yield (0, workspace_utilities_1.coerceIdeaExcludeFolders)(tree, [
                (0, path_1.join)(project.root, 'docs'),
            ]);
        }
    });
}
//# sourceMappingURL=init-project.js.map