"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initGenerator = initGenerator;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const utilities_1 = require("@rxap/utilities");
const workspace_utilities_1 = require("@rxap/workspace-utilities");
const init_project_1 = require("../init-application/init-project");
const init_project_2 = require("../init-library/init-project");
const init_workspace_1 = require("./init-workspace");
const path_1 = require("path");
function skipProject(tree, options, project, projectName) {
    var _a;
    if ((0, workspace_utilities_1.IsWorkspaceProject)(project)) {
        return false;
    }
    if (!tree.exists((0, path_1.join)((0, workspace_utilities_1.GetProjectRoot)(project), 'tsconfig.json'))) {
        return true;
    }
    if (!tree.exists((0, path_1.join)((0, workspace_utilities_1.GetProjectSourceRoot)(project), 'index.ts'))) {
        return true;
    }
    if ((_a = project.tags) === null || _a === void 0 ? void 0 : _a.includes('internal')) {
        return true;
    }
    if ((0, workspace_utilities_1.IsLibraryProject)(project)) {
        return false;
    }
    return true;
}
function initGenerator(tree, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        var _a, _b;
        (_a = options.project) !== null && _a !== void 0 ? _a : (options.project = undefined);
        (_b = options.projects) !== null && _b !== void 0 ? _b : (options.projects = []);
        if (options.project) {
            (0, utilities_1.CoerceArrayItems)(options.projects, [options.project]);
        }
        console.log('typedoc init generator:', options);
        yield (0, init_workspace_1.initWorkspace)(tree, options);
        for (const [projectName, project] of (0, workspace_utilities_1.ForeachInitProject)(tree, options, skipProject)) {
            if ((0, workspace_utilities_1.IsApplicationProject)(project)) {
                yield (0, init_project_1.initProject)(tree, projectName, project, options);
            }
            if ((0, workspace_utilities_1.IsLibraryProject)(project)) {
                yield (0, init_project_2.initProject)(tree, projectName, project, options);
            }
            if ((0, workspace_utilities_1.IsWorkspaceProject)(project)) {
                yield (0, init_project_2.initProject)(tree, projectName, project, options);
            }
        }
        (0, workspace_utilities_1.GenerateSerializedSchematicFile)(tree, '/', '@rxap/plugin-typedoc', 'init', options);
        if (!options.skipFormat) {
            yield (0, devkit_1.formatFiles)(tree);
        }
    });
}
exports.default = initGenerator;
//# sourceMappingURL=generator.js.map