"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createNodesV2 = void 0;
exports.normalizeOptions = normalizeOptions;
const tslib_1 = require("tslib");
const workspace_utilities_1 = require("@rxap/workspace-utilities");
const path_1 = require("path");
require("colors");
const tree_1 = require("nx/src/generators/tree");
function normalizeOptions(options) {
    return options !== null && options !== void 0 ? options : {};
}
exports.createNodesV2 = [
    '**/tsconfig.typedoc.json',
    (configFilePaths, options, context) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const normalizedOptions = normalizeOptions(options);
        const includedConfigFilePaths = yield Promise.all(configFilePaths.map((configFilePath) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            if (yield shouldHaveProjectConfiguration(configFilePath, normalizedOptions, context)) {
                return configFilePath;
            }
            return undefined;
        }))).then((configFilePathOrUndefinedList) => configFilePathOrUndefinedList.filter((value) => value !== undefined));
        const results = yield Promise.all(includedConfigFilePaths.map((configFilePath) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            const [projectPath, projectConfiguration] = yield createProjectConfiguration(configFilePath, normalizedOptions, context);
            return [configFilePath, projectPath, projectConfiguration];
        })));
        return results.map(([configFilePath, projectPath, projectConfiguration]) => [
            configFilePath,
            {
                projects: {
                    [projectPath]: projectConfiguration,
                },
            },
        ]);
    }),
];
function shouldHaveProjectConfiguration(configFilePath, options, context) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const projectPath = (0, path_1.dirname)(configFilePath);
        const tree = new tree_1.FsTree(context.workspaceRoot, false);
        const projectConfiguration = (0, workspace_utilities_1.FindProjectByPath)(tree, projectPath);
        if (!projectConfiguration) {
            // console.log(`The folder of the file '${ configFilePath }' is not the root of a project. Skipping`.yellow);
            return false;
        }
        return true;
    });
}
function createProjectConfiguration(configFilePath, options, context) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const projectPath = (0, path_1.dirname)(configFilePath);
        const targets = {};
        const tree = new tree_1.FsTree(context.workspaceRoot, false);
        const projectConfiguration = (0, workspace_utilities_1.FindProjectByPath)(tree, projectPath);
        if (!projectConfiguration) {
            throw new Error(`Could not find project in '${projectPath}'`);
        }
        targets['typedoc'] = createTypedocTarget(tree, projectConfiguration);
        return [
            projectPath, {
                targets,
            },
        ];
    });
}
function findTsConfigOption(tree, { root }) {
    if (tree.exists((0, path_1.join)(root, 'tsconfig.typedoc.json'))) {
        return (0, path_1.join)(root, 'tsconfig.typedoc.json');
    }
    if (tree.exists((0, path_1.join)(root, 'tsconfig.lib.json'))) {
        return (0, path_1.join)(root, 'tsconfig.lib.json');
    }
    if (tree.exists((0, path_1.join)(root, 'tsconfig.json'))) {
        return (0, path_1.join)(root, 'tsconfig.json');
    }
    throw new Error(`Could not find a tsconfig.*.json or tsconfig.json in the project root: '${root}'`);
}
function findEntryPoints(tree, projectConfiguration) {
    const { root } = projectConfiguration;
    if ((0, workspace_utilities_1.IsStandaloneWorkspace)(tree)) {
        return [(0, path_1.join)(root, 'src/index.ts')];
    }
    if (!tree.exists((0, path_1.join)(root, 'src/index.ts'))) {
        throw new Error(`The project ${projectConfiguration.name} has a tsconfig.typedoc.json but not a 'src/index.ts' (${projectConfiguration.root})`);
    }
    return [(0, path_1.join)(root, 'src/index.ts')];
}
function createTypedocTarget(tree, projectConfiguration) {
    const options = {};
    if (!(0, workspace_utilities_1.IsWorkspaceProject)(projectConfiguration)) {
        options['tsconfig'] = findTsConfigOption(tree, projectConfiguration);
        options['entryPoints'] = findEntryPoints(tree, projectConfiguration);
        options['includeVersion'] = true;
        options['entryPointStrategy'] = 'expand';
        options['name'] = (0, workspace_utilities_1.GetProjectPackageJson)(tree, projectConfiguration.name).name;
    }
    options['json'] = true;
    options['html'] = true;
    const packageJson = (0, workspace_utilities_1.GetRootPackageJson)(tree);
    options['markdown'] = 'typedoc-plugin-markdown' in packageJson.devDependencies;
    options['wiki'] = 'typedoc-plugin-markdown' in packageJson.devDependencies && 'typedoc-github-wiki-theme' in packageJson.devDependencies;
    options['skipErrorChecking'] = true;
    return {
        executor: '@rxap/plugin-typedoc:build',
        inputs: ["production", "^production"],
        outputs: ['{projectRoot}/docs'],
        cache: true,
        options
    };
}
//# sourceMappingURL=plugin.js.map